----------------------------------------------------------
Welcome to Django REST framework reCAPTCHA's documentation
----------------------------------------------------------

Django REST framework reCAPTCHA provides you a serializer field to handle and
validate Google reCAPTCHA response.

See our :doc:`Changelog </history>` for information on updates.

Requirements
============

* Python: 2.7, 3.4, 3.5, 3.6
* Django: 1.10, 1.11, 2.0
* Django REST framework: 3.4, 3.5, 3.6, 3.7, 3.8

Sources
=======

``djangorestframework-recaptcha`` is hosted on
`Github <https://github.com/Maximilien-R/django-rest-framework-recaptcha>`_.

Index
=====

.. toctree::
   :maxdepth: 1

   installation
   usage
   contributing
   authors
   history
